import AdminGuard from "@validators/AdminGuard";
import UserGuard from "@validators/UserGuard";
import express, { type Router } from "express";
import VehicleController from "@controllers/vehicle.controller";
import RentController from "@controllers/rent.controller";

const RentRouter: Router = express.Router();

// Get rent affected to the user
RentRouter.route("/affected").get(UserGuard, RentController.getAssignedToUser);

// Get all vehicle in rent (admin only)
RentRouter.route("/affected/all").get(AdminGuard, RentController.getAll);

// Add a new vehicle (admin only)
RentRouter.route("/veh/new").post(AdminGuard, VehicleController.create);

// Get all vehicles
RentRouter.route("/veh/all").get(VehicleController.getAll);

// Rent a specific vehicle
RentRouter.route("/veh/rent/:vehicleId").post(UserGuard);

RentRouter.route("/veh/:vehicleId")
	.get(UserGuard, VehicleController.getById)
	.patch(AdminGuard, VehicleController.update)
	.delete(AdminGuard, VehicleController.delete);

export default RentRouter;
